<?php

/*
Plugin Name: Cf7 Virtual Success Page
Plugin URI: http://www.ajaxy.org/
Description: Creates a Virtual Success Page for Contact Form 7 ajax submit.
Author: Naji Amer - @n-for-all
Author URI: http://ajaxy.org/
Text Domain: cf7-success-page
Version: 1.0.0
*/

if (is_admin()) {
    require_once 'admin/license.php';
}

/* Not tested with older versions of wpcf7, lower the version number at your own risk */
define("WPCF7_SUCCESS_PAGE_VERSION", "5.0");


define("WPCF7_SUCCESS_PAGE_TEXT_DOMAIN", "cf7-fields-success_page");
define("WPCF7_SUCCESS_PAGE_PLUGIN_URL", plugins_url('', __FILE__));

class WPCF7_Success_Page
{
    private $license = null;
    public function __construct()
    {
        global $AJAXY_CF7_Success_Page_License;
        $this->license = $AJAXY_CF7_Success_Page_License;
        add_action('wpcf7_init', array(&$this, 'wpcf7_init'));
    }
    public function wpcf7_init()
    {
        if (version_compare(WPCF7_VERSION, WPCF7_SUCCESS_PAGE_VERSION) >= 0) {
            $this->filters();
            $this->actions();
        } else {
            add_action('admin_notices', array(&$this, 'version_notice__error'));
        }
    }
    public function filters()
    {
        add_filter('wpcf7_editor_panels', array(&$this, 'editor_panels'), 10, 1);
        add_filter('wpcf7_contact_form_properties', array(&$this, 'properties'), 10, 2);
        add_filter('wpcf7_form_elements', array(&$this, 'wpcf7_form_elements'), 10, 1);
    }
    public function actions()
    {
        add_action('wpcf7_save_contact_form', array(&$this, 'save_success_page'), 10, 1);
        add_action('admin_enqueue_scripts', array(&$this, 'admin_scripts'));

        if (is_admin()) {
            add_action('admin_init', array(&$this, 'admin_init'), 56);
        }
        add_action('wpcf7_enqueue_scripts', array(&$this, 'scripts'));
    }

    public function version_notice__error()
    {
        $class = 'notice notice-error';
        $message = __('Contact form 7 Success Page requires Contact Form 7 version '.WPCF7_SUCCESS_PAGE_VERSION.' or higher.', 'cf7-success-page');

        printf('<div class="%1$s"><p>%2$s</p></div>', $class, $message);
    }

    public function admin_init()
    {
    }
    public function wpcf7_form_elements($tags)
    {
        if (! $contact_form = wpcf7_get_current_contact_form()) {
            return $tags;
        }
        if(empty((array)$contact_form->prop('success_page'))){
            return $tags;
        }
        return $tags.'<script>
            if(typeof window.ajaxy_success_page == "undefined"){
                window.ajaxy_success_page = [];
            }
            window.ajaxy_success_page.push('.json_encode(array('id' => $contact_form->id(), 'settings' => (array)$contact_form->prop('success_page'))).');
        </script>';
    }

    public function save_success_page($contact_form)
    {
        $properties = array();
        if (isset($_POST['success_page']) && sizeof($_POST['success_page']) > 0) {
            $properties['success_page'] = $_POST['success_page'];
        }
        $properties = array_merge($contact_form->get_properties(), $properties);
        $contact_form->set_properties($properties);
    }
    public function editor_panels($panels)
    {
        $panels['success_page-panel'] = array(
          'title' => __('Success Page', WPCF7_SUCCESS_PAGE_TEXT_DOMAIN),
          'callback' => array(&$this, 'editor_panel')
        );
        return $panels;
    }
    public function editor_panel($post)
    {
        $success_page = (array)$post->prop('success_page'); ?>

        <?php if ($this->license->is_licensed()): ?>
        <?php
        $list = array(
            'fb' => array('Facebook', 'ex: /thankyou'),
            'ga' => array('Google Analytics', 'ex: /thankyou'),
            'custom' => array('Custom Script', 'ex: alert();')
        );
        ?>
        <div id="wpcf7-success_page-list">
            <h3><?php echo esc_html(__('Success Page', WPCF7_SUCCESS_PAGE_TEXT_DOMAIN)); ?></h3>
            <?php foreach ($list as $key => $label) { ?>
                <div class="wpcf7-success_page-item">
                    <label><?php echo $label[0]; ?></label>
                    <?php if($key == 'custom'): ?>
                        <textarea style="width:98%;min-height:200px;" name="success_page[<?php echo $key; ?>]" ><?php echo isset($success_page[$key]) ? $success_page[$key]: '' ?></textarea>
                    <?php else: ?>
                        <input placeholder="<?php echo $label[1]; ?>" value="<?php echo isset($success_page[$key]) ? $success_page[$key]: '' ?>" type="text" name="success_page[<?php echo $key; ?>]" />
                    <?php endif; ?>
                </div>
            <?php } ?>
        </div>

        <?php else: ?>
            <div class="wpcf7-success_page-unlock">
                <a href="<?php echo admin_url('admin.php?page=wpcf7-success_page'); ?>" class="button button-primary">Activate</a>
            </div>
        <?php endif;
    }
    public function properties($properties, $WPCF7_ContactForm)
    {
        if (!isset($properties['success_page'])) {
            $properties['success_page'] = array();
        }
        return $properties;
    }
    public function admin_scripts()
    {
        wp_enqueue_style(WPCF7_SUCCESS_PAGE_TEXT_DOMAIN."-style", WPCF7_SUCCESS_PAGE_PLUGIN_URL. '/admin/css/styles.css');
    }
    public function scripts()
    {
        $in_footer = true;
        if ('header' === wpcf7_load_js()) {
            $in_footer = false;
        }
        wp_enqueue_script( WPCF7_SUCCESS_PAGE_TEXT_DOMAIN, WPCF7_SUCCESS_PAGE_PLUGIN_URL. '/js/front.js', array( 'contact-form-7' ), "1.0.0", $in_footer);
    }
}

global $WPCF7_Success_Page;
$WPCF7_Success_Page = new WPCF7_Success_Page();

?>
